@@ -12,6 +12,7 @@ import sys
 ROOT_DIR = Path( Path(__file__).parent.resolve() )
 MODELS_PATH = ROOT_DIR / "BP3Models"
 ESM_SCRIPT_PATH = ROOT_DIR / "extract.py"
+ESM_LOCAL_SCRIPT_PATH = ROOT_DIR / "extract_local.py"
 
 ### SET GPU OR CPU ###
 if torch.cuda.is_available():
@@ -107,7 +108,7 @@ class MyDenseNet(nn.Module):
 
 class Antigens():
     def __init__(self, fasta_file, esm1b_encoding_dir,
-        add_seq_len=False):
+        add_seq_len=False, run_esm_model_local=False):
         """
         Initialize Antigens class object
         Inputs:
@@ -115,6 +116,7 @@ class Antigens():
         """
 
         self.esm1b_encoding_dir = esm1b_encoding_dir
+        self.run_esm_model_local = run_esm_model_local
 
         try:
             esm1b_encoding_dir.mkdir(parents=True, exist_ok=False)
@@ -151,8 +153,11 @@ class Antigens():
     def call_esm1b_script(self):
         fastaPath = self.esm1b_encoding_dir / "antigens.fasta"
         
-        try:
-            subprocess.check_call(['python', ESM_SCRIPT_PATH, "esm1b_t33_650M_UR50S", fastaPath, self.esm1b_encoding_dir, "--include", "per_tok", "--truncate"])
+        try: #only using this for biolib implementation 
+            if self.run_esm_model_local:
+                subprocess.check_call(['python', ESM_LOCAL_SCRIPT_PATH, "local", fastaPath, self.esm1b_encoding_dir, "--include", "per_tok", "--truncate"])
+            else:
+                subprocess.check_call(['python', ESM_SCRIPT_PATH, "esm1b_t33_650M_UR50S", fastaPath, self.esm1b_encoding_dir, "--include", "per_tok", "--truncate"])
         except subprocess.CalledProcessError as error:
             sys.exit(f"ESM-1b model could not be run with following error message: {error}.\nThis is likely a memory issue.")
 
